@@ -18,8 +18,20 @@ WORKSPACE_HEADER_NAME = "X-Argilla-Workspace"
 
 DEFAULT_USERNAME = "argilla"
 DEFAULT_PASSWORD = "1234"
+DEFAULT_API_URL = "http://localhost:6900"
 DEFAULT_API_KEY = "argilla.apikey"
 DEFAULT_MAX_KEYWORD_LENGTH = 128
 DEFAULT_TELEMETRY_KEY = "C6FkcaoCbt78rACAgvyBxGBcMB3dM3nn"
 
+# The metadata field name prefix defined for protected (non-searchable) values
+PROTECTED_METADATA_FIELD_PREFIX = "_"
+
 ES_INDEX_REGEX_PATTERN = r"^(?!-|_)[a-z0-9-_]+$"
+
+# constants for prepare_for_training(framework="openai")
+OPENAI_SEPARATOR = "\n\n###\n\n"
+OPENAI_END_TOKEN = " END"
+OPENAI_WHITESPACE = " "
+OPENAI_LEGACY_MODELS = ["babbage", "davinci", "curie", "ada"]
+
+_JS_MAX_SAFE_INTEGER = 9007199254740991
