@@ -12,18 +12,20 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-import logging
+
+import asyncio
+import warnings
 from asyncio import Future
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 
 from argilla.client.client import Argilla
 from argilla.client.datasets import Dataset
-from argilla.client.models import (  # TODO Remove TextGenerationRecord
-    BulkResponse,
-    Record,
-)
-
-_LOGGER = logging.getLogger(__name__)
+from argilla.client.models import BulkResponse, Record  # TODO Remove TextGenerationRecord
+from argilla.client.sdk.commons import errors
+from argilla.client.sdk.datasets.models import Dataset as DatasetModel
+from argilla.client.sdk.v1.datasets.api import list_datasets as list_datasets_api_v1
+from argilla.client.sdk.v1.workspaces.models import WorkspaceModel
+from argilla.client.sdk.workspaces.api import list_workspaces as list_workspaces_api_v0
 
 Api = Argilla  # Backward compatibility
 
@@ -40,7 +42,7 @@ class ArgillaSingleton:
         return cls._INSTANCE
 
     @classmethod
-    def clear(cls):
+    def clear(cls) -> None:
         cls._INSTANCE = None
 
     @classmethod
@@ -71,11 +73,13 @@ def init(
     workspace: Optional[str] = None,
     timeout: int = 60,
     extra_headers: Optional[Dict[str, str]] = None,
-):
+) -> None:
     """Init the Python client.
 
-    We will automatically init a default client for you when calling other client methods.
-    The arguments provided here will overwrite your corresponding environment variables.
+    If this function is called with `api_url=None` and `api_key=None` and no values have been set for the environment
+    variables `ARGILLA_API_URL` and `ARGILLA_API_KEY`, then the local credentials stored by a previous call to `argilla
+    login` command will be used. If local credentials are not found, then `api_url` and `api_key` will fallback to the
+    default values.
 
     Args:
         api_url: Address of the REST API. If `None` (default) and the env variable ``ARGILLA_API_URL`` is not set,
@@ -96,7 +100,6 @@ def init(
         >>> headers = {"X-Client-id":"id","X-Secret":"secret"}
         >>> rg.init(api_url="http://localhost:9090", api_key="4AkeAPIk3Y", extra_headers=headers)
     """
-
     ArgillaSingleton.init(
         api_url=api_url,
         api_key=api_key,
@@ -112,10 +115,12 @@ def log(
     workspace: Optional[str] = None,
     tags: Optional[Dict[str, str]] = None,
     metadata: Optional[Dict[str, Any]] = None,
-    batch_size: int = 500,
+    batch_size: int = 100,
     verbose: bool = True,
     background: bool = False,
     chunk_size: Optional[int] = None,
+    num_threads: int = 0,
+    max_retries: int = 3,
 ) -> Union[BulkResponse, Future]:
     """Logs Records to argilla.
 
@@ -133,6 +138,10 @@ def log(
         background: If True, we will NOT wait for the logging process to finish and return an ``asyncio.Future``
             object. You probably want to set ``verbose`` to False in that case.
         chunk_size: DEPRECATED! Use `batch_size` instead.
+        num_threads: If > 0, will use num_thread separate number threads to batches, sending data concurrently.
+                Default to `0`, which means no threading at all.
+        max_retries: Number of retries when logging a batch of records if a `httpx.TransportError` occurs.
+                Default `3`.
 
     Returns:
         Summary of the response from the REST API.
@@ -162,6 +171,8 @@ def log(
         verbose=verbose,
         background=background,
         chunk_size=chunk_size,
+        num_threads=num_threads,
+        max_retries=max_retries,
     )
 
 
@@ -171,7 +182,7 @@ async def log_async(
     workspace: Optional[str] = None,
     tags: Optional[Dict[str, str]] = None,
     metadata: Optional[Dict[str, Any]] = None,
-    batch_size: int = 500,
+    batch_size: int = 100,
     verbose: bool = True,
     chunk_size: Optional[int] = None,
 ) -> BulkResponse:
@@ -201,7 +212,16 @@ async def log_async(
         ...     rg.log_async(my_records, dataset_name), loop
         ... )
     """
-    return await ArgillaSingleton.get().log_async(
+
+    warnings.warn(
+        (
+            "`log_async` is deprecated and will be removed in next release. "
+            "Please, use `log` with `background=True` instead"
+        ),
+        DeprecationWarning,
+    )
+
+    future = ArgillaSingleton.get().log(
         records=records,
         name=name,
         workspace=workspace,
@@ -210,8 +230,27 @@ async def log_async(
         batch_size=batch_size,
         verbose=verbose,
         chunk_size=chunk_size,
+        background=True,
     )
 
+    return await asyncio.wrap_future(future)
+
+
+def _check_if_feedback_dataset_exists(client: Argilla, name: str, workspace: str) -> bool:
+    response = list_workspaces_api_v0(client.http_client.httpx)
+    workspace_id = None
+    for ws in response.parsed:
+        if ws.name == workspace:
+            workspace_id = ws.id
+            break
+
+    response = list_datasets_api_v1(client.http_client.httpx)
+    for dataset in response.parsed:
+        if dataset.name == name and dataset.workspace_id == workspace_id:
+            return True
+
+    return False
+
 
 def load(
     name: str,
@@ -223,7 +262,9 @@ def load(
     sort: Optional[List[Tuple[str, str]]] = None,
     id_from: Optional[str] = None,
     batch_size: int = 250,
-    as_pandas=None,
+    include_vectors: bool = True,
+    include_metrics: bool = True,
+    as_pandas: Optional[bool] = None,
 ) -> Dataset:
     """Loads a argilla dataset.
 
@@ -238,10 +279,14 @@ def load(
         limit: The number of records to retrieve.
         sort: The fields on which to sort [(<field_name>, 'asc|decs')].
         id_from: If provided, starts gathering the records starting from that Record.
-            As the Records returned with the load method are sorted by ID, ´id_from´
+            As the Records returned with the load method are sorted by ID, `id_from`
             can be used to load using batches.
         batch_size: If provided, load `batch_size` samples per request. A lower batch
             size may help avoid timeouts.
+        include_vectors: When set to `False`, indicates that records will be retrieved excluding their vectors,
+            if any. By default, this parameter is set to `True`, meaning that vectors will be included.
+        include_metrics: When set to `False`, indicates that records will be retrieved excluding their metrics.
+            By default, this parameter is set to `True`, meaning that metrics will be included.
         as_pandas: DEPRECATED! To get a pandas DataFrame do
             ``rg.load('my_dataset').to_pandas()``.
 
@@ -266,25 +311,33 @@ def load(
         >>> dataset_batch_2 = rg.load(name="example-dataset", limit=1000, id_from=dataset_batch_1[-1].id)
 
     """
-    return ArgillaSingleton.get().load(
-        name=name,
-        workspace=workspace,
-        query=query,
-        vector=vector,
-        ids=ids,
-        limit=limit,
-        sort=sort,
-        id_from=id_from,
-        batch_size=batch_size,
-        as_pandas=as_pandas,
-    )
+    argilla = ArgillaSingleton.get()
+    try:
+        return argilla.load(
+            name=name,
+            workspace=workspace,
+            query=query,
+            vector=vector,
+            ids=ids,
+            limit=limit,
+            sort=sort,
+            id_from=id_from,
+            batch_size=batch_size,
+            include_metrics=include_metrics,
+            include_vectors=include_vectors,
+            as_pandas=as_pandas,
+        )
+    except errors.NotFoundApiError as e:
+        workspace = workspace or argilla.get_workspace()
+        if _check_if_feedback_dataset_exists(client=argilla, name=name, workspace=workspace):
+            raise ValueError(
+                f"The dataset '{name}' exists but it is a `FeedbackDataset`. Use `rg.FeedbackDataset.from_argilla`"
+                " instead to load it."
+            )
+        raise e
 
 
-def copy(
-    dataset: str,
-    name_of_copy: str,
-    workspace: str = None,
-):
+def copy(dataset: str, name_of_copy: str, workspace: Optional[str] = None) -> None:
     """
     Creates a copy of a dataset including its tags and metadata
 
@@ -298,14 +351,14 @@ def copy(
         >>> rg.copy("my_dataset", name_of_copy="new_dataset")
         >>> rg.load("new_dataset")
     """
-    return ArgillaSingleton.get().copy(
+    ArgillaSingleton.get().copy(
         dataset=dataset,
         name_of_copy=name_of_copy,
         workspace=workspace,
     )
 
 
-def delete(name: str, workspace: Optional[str] = None):
+def delete(name: str, workspace: Optional[str] = None) -> None:
     """
     Deletes a dataset.
 
@@ -336,7 +389,7 @@ def delete_records(
         workspace: The workspace to which records will be logged/loaded. If `None` (default) and the
             env variable ``ARGILLA_WORKSPACE`` is not set, it will default to the private user workspace.
         query: An ElasticSearch query with the `query string syntax
-            <https://rubrix.readthedocs.io/en/stable/guides/queries.html>`_
+            <https://docs.argilla.io/en/latest/guides/query_datasets.html>`_
         ids: If provided, deletes dataset records with given ids.
         discard_only: If `True`, matched records won't be deleted. Instead, they will be marked as `Discarded`
         discard_when_forbidden: Only super-user or dataset creator can delete records from a dataset.
@@ -367,7 +420,7 @@ def delete_records(
     )
 
 
-def set_workspace(workspace: str):
+def set_workspace(workspace: str) -> None:
     """Sets the active workspace.
 
     Args:
@@ -385,6 +438,39 @@ def get_workspace() -> str:
     return ArgillaSingleton.get().get_workspace()
 
 
+def list_workspaces() -> List[WorkspaceModel]:
+    """Lists all the available workspaces for the current user.
+
+    Returns:
+        A list of `WorkspaceModel` objects, containing the workspace
+        attributes: name, id, created_at, and updated_at.
+    """
+    warnings.warn(
+        "`Workspace.list` is recommended over `list_workspaces`, since you can easily"
+        " access the workspaces as a list of `Workspace` objects with their attributes"
+        " and methods.",
+        UserWarning,
+        stacklevel=1,
+    )
+    return ArgillaSingleton.get().list_workspaces()
+
+
+def list_datasets(workspace: Optional[str] = None) -> List[DatasetModel]:
+    """Lists all the available datasets for the current user in Argilla.
+
+    Args:
+        workspace: If provided, list datasets from that workspace only. Note that
+            the workspace must exist in advance, otherwise a HTTP 400 error will be
+            raised.
+
+    Returns:
+        A list of `DatasetModel` objects, containing the dataset
+        attributes: tags, metadata, name, id, task, owner, workspace, created_at,
+        and last_updated.
+    """
+    return ArgillaSingleton.get().list_datasets(workspace=workspace)
+
+
 def active_client() -> Argilla:
     """Returns the active argilla client.
 
