@@ -12,25 +12,30 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import asyncio
 import logging
 import os
 import re
 import warnings
 from asyncio import Future
+from concurrent.futures import ThreadPoolExecutor
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 
+import backoff
+import httpx
 from rich import print as rprint
 from rich.progress import Progress
 
 from argilla._constants import (
     DEFAULT_API_KEY,
+    DEFAULT_API_URL,
+    DEFAULT_USERNAME,
     ES_INDEX_REGEX_PATTERN,
     WORKSPACE_HEADER_NAME,
 )
 from argilla.client.apis.datasets import Datasets
 from argilla.client.apis.metrics import MetricsAPI
 from argilla.client.apis.search import Search, VectorSearch
+from argilla.client.apis.status import Status
 from argilla.client.datasets import (
     Dataset,
     DatasetForText2Text,
@@ -46,21 +51,14 @@ from argilla.client.models import (
     TokenClassificationRecord,
 )
 from argilla.client.sdk.client import AuthenticatedClient
-from argilla.client.sdk.commons.api import async_bulk
-from argilla.client.sdk.commons.errors import (
-    AlreadyExistsApiError,
-    ApiCompatibilityError,
-    InputValueError,
-    NotFoundApiError,
-)
+from argilla.client.sdk.commons.api import bulk
+from argilla.client.sdk.commons.errors import AlreadyExistsApiError, InputValueError, NotFoundApiError
 from argilla.client.sdk.datasets import api as datasets_api
 from argilla.client.sdk.datasets.models import CopyDatasetRequest, TaskType
+from argilla.client.sdk.datasets.models import Dataset as DatasetModel
 from argilla.client.sdk.metrics import api as metrics_api
 from argilla.client.sdk.metrics.models import MetricInfo
-from argilla.client.sdk.text2text.models import (
-    CreationText2TextRecord,
-    Text2TextBulkData,
-)
+from argilla.client.sdk.text2text.models import CreationText2TextRecord, Text2TextBulkData
 from argilla.client.sdk.text2text.models import Text2TextRecord as SdkText2TextRecord
 from argilla.client.sdk.text_classification import api as text_classification_api
 from argilla.client.sdk.text_classification.models import (
@@ -68,44 +66,20 @@ from argilla.client.sdk.text_classification.models import (
     LabelingRule,
     LabelingRuleMetricsSummary,
     TextClassificationBulkData,
-    TextClassificationQuery,
-)
-from argilla.client.sdk.text_classification.models import (
-    TextClassificationRecord as SdkTextClassificationRecord,
 )
+from argilla.client.sdk.text_classification.models import TextClassificationRecord as SdkTextClassificationRecord
 from argilla.client.sdk.token_classification.models import (
     CreationTokenClassificationRecord,
     TokenClassificationBulkData,
-    TokenClassificationQuery,
-)
-from argilla.client.sdk.token_classification.models import (
-    TokenClassificationRecord as SdkTokenClassificationRecord,
 )
+from argilla.client.sdk.token_classification.models import TokenClassificationRecord as SdkTokenClassificationRecord
 from argilla.client.sdk.users import api as users_api
-from argilla.client.sdk.users.models import User
-from argilla.utils import setup_loop_in_thread
+from argilla.client.sdk.v1.workspaces import api as workspaces_api_v1
+from argilla.client.sdk.v1.workspaces.models import WorkspaceModel
 
 _LOGGER = logging.getLogger(__name__)
 
 
-class _ArgillaLogAgent:
-    def __init__(self, api: "Argilla"):
-        self.__api__ = api
-        self.__loop__, self.__thread__ = setup_loop_in_thread()
-
-    @staticmethod
-    async def __log_internal__(api: "Argilla", *args, **kwargs):
-        try:
-            return await api.log_async(*args, **kwargs)
-        except Exception as ex:
-            dataset = kwargs["name"]
-            _LOGGER.error(f"\nCannot log data in dataset '{dataset}'\nError: {type(ex).__name__}\nDetails: {ex}")
-            raise ex
-
-    def log(self, *args, **kwargs) -> Future:
-        return asyncio.run_coroutine_threadsafe(self.__log_internal__(self.__api__, *args, **kwargs), self.__loop__)
-
-
 class Argilla:
     """
     The main argilla client.
@@ -119,10 +93,16 @@ class Argilla:
         api_url: Optional[str] = None,
         api_key: Optional[str] = None,
         workspace: Optional[str] = None,
-        timeout: int = 60,
+        timeout: int = 120,
         extra_headers: Optional[Dict[str, str]] = None,
     ):
         """
+        Inits `Argilla` instance.
+
+        If called with `api_url=None` and `api_key=None` and no values have been set for the environment variables
+        `ARGILLA_API_URL` and `ARGILLA_API_KEY`, then the local credentials stored by a previous call to `argilla login`
+        command will be used. If local credentials are not found, then `api_url` and `api_key` will fallback to the
+        default values.
 
         Args:
             api_url: Address of the REST API. If `None` (default) and the env variable ``ARGILLA_API_URL`` is not set,
@@ -136,11 +116,29 @@ class Argilla:
                 the headers of argilla client requests, like additional security restrictions. Default: `None`.
 
         """
-        api_url = api_url or os.getenv("ARGILLA_API_URL", "http://localhost:6900")
+        from argilla.client.login import ArgillaCredentials
+
+        api_url = api_url or os.getenv("ARGILLA_API_URL")
+        api_key = api_key or os.getenv("ARGILLA_API_KEY")
+        workspace = workspace or os.getenv("ARGILLA_WORKSPACE")
+        extra_headers = extra_headers or {}
+
+        if api_url is None and api_key is None:
+            try:
+                credentials = ArgillaCredentials.load()
+                api_url = credentials.api_url
+                api_key = credentials.api_key
+                if not workspace:
+                    workspace = credentials.workspace
+                extra_headers = credentials.extra_headers
+            except FileNotFoundError:
+                pass
+
+        api_url = api_url or DEFAULT_API_URL
+        api_key = api_key or DEFAULT_API_KEY
+
         # Checking that the api_url does not end in '/'
         api_url = re.sub(r"\/$", "", api_url)
-        api_key = api_key or os.getenv("ARGILLA_API_KEY", DEFAULT_API_KEY)
-        workspace = workspace or os.getenv("ARGILLA_WORKSPACE")
         headers = extra_headers or {}
 
         self._client: AuthenticatedClient = AuthenticatedClient(
@@ -150,16 +148,49 @@ class Argilla:
             headers=headers.copy(),
         )
 
-        self._user: User = users_api.whoami(client=self._client)
-        self.set_workspace(workspace or self._user.username)
+        self._user = users_api.whoami(client=self.http_client)  # .parsed
 
-        self._agent = _ArgillaLogAgent(self)
+        if not workspace and self._user.username == DEFAULT_USERNAME and DEFAULT_USERNAME in self._user.workspaces:
+            warnings.warn(
+                "Default user was detected and no workspace configuration was provided,"
+                f" so the default {DEFAULT_USERNAME!r} workspace will be used. If you"
+                " want to setup another workspace, use the `rg.set_workspace` function"
+                " or provide a different one on `rg.init`",
+                category=UserWarning,
+            )
+            workspace = DEFAULT_USERNAME
+        if workspace:
+            self.set_workspace(workspace or self._user.username)
+        else:
+            warnings.warn(
+                "No workspace configuration was detected. To work with Argilla"
+                " datasets, specify a valid workspace name on `rg.init` or set it"
+                " up through the `rg.set_workspace` function.",
+                category=UserWarning,
+            )
+
+        self._check_argilla_versions()
+
+    def _check_argilla_versions(self):
+        from argilla import __version__ as rg_version
+
+        api_info = Status(self.http_client).get_info()
+
+        client_version = rg_version.split(".")[:2]
+        server_version = api_info.version.split(".")[:2]
+        if client_version != server_version:
+            warnings.warn(
+                message=f"You're connecting to Argilla Server {api_info.version} using a different client version "
+                f"({rg_version}).\n"
+                "This may lead to potential compatibility issues during your experience.\n"
+                "To ensure a seamless and optimized connection, we highly recommend "
+                "aligning your client version with the server version.",
+                category=UserWarning,
+            )
 
     def __del__(self):
         if hasattr(self, "_client"):
             del self._client
-        if hasattr(self, "_agent"):
-            del self._agent
 
     @property
     def client(self) -> AuthenticatedClient:
@@ -178,12 +209,12 @@ class Argilla:
     @property
     def datasets(self) -> Datasets:
         """Datasets API primitives"""
-        return Datasets(client=self._client)
+        return Datasets(client=self.http_client)
 
     @property
     def search(self):
         """Search API primitives"""
-        return Search(client=self._client)
+        return Search(client=self.http_client)
 
     @property
     def metrics(self):
@@ -214,10 +245,10 @@ class Argilla:
             )
 
         if workspace != self.get_workspace():
-            if workspace == self.user.username or (self.user.workspaces and workspace in self.user.workspaces):
-                self._client.headers[WORKSPACE_HEADER_NAME] = workspace
+            if workspace in [ws.name for ws in self.list_workspaces()]:
+                self.http_client.update_headers({WORKSPACE_HEADER_NAME: workspace})
             else:
-                raise Exception(f"Wrong provided workspace {workspace}")
+                raise ValueError(f"Wrong provided workspace {workspace!r}")
 
     def get_workspace(self) -> str:
         """Returns the name of the active workspace.
@@ -225,9 +256,33 @@ class Argilla:
         Returns:
             The name of the active workspace as a string.
         """
-        return self._client.headers.get(WORKSPACE_HEADER_NAME)
+        return self.http_client.headers.get(WORKSPACE_HEADER_NAME)
 
-    def copy(self, dataset: str, name_of_copy: str, workspace: str = None):
+    def list_workspaces(self) -> List[WorkspaceModel]:
+        """Lists all the available workspaces for the current user.
+
+        Returns:
+            A list of `WorkspaceModel` objects, containing the workspace
+            attributes: name, id, created_at, and updated_at.
+        """
+        return workspaces_api_v1.list_workspaces_me(client=self.http_client.httpx).parsed
+
+    def list_datasets(self, workspace: Optional[str] = None) -> List[DatasetModel]:
+        """Lists all the available datasets for the current user in Argilla.
+
+        Args:
+            workspace: If provided, list datasets from that workspace only. Note that
+                the workspace must exist in advance, otherwise a HTTP 400 error will be
+                raised.
+
+        Returns:
+            A list of `DatasetModel` objects, containing the dataset
+            attributes: tags, metadata, name, id, task, owner, workspace, created_at,
+            and last_updated.
+        """
+        return datasets_api.list_datasets(client=self.http_client, workspace=workspace).parsed
+
+    def copy(self, dataset: str, name_of_copy: str, workspace: Optional[str] = None) -> None:
         """Creates a copy of a dataset including its tags and metadata
 
         Args:
@@ -237,12 +292,9 @@ class Argilla:
 
         """
         datasets_api.copy_dataset(
-            client=self._client,
+            client=self.http_client,
             name=dataset,
-            json_body=CopyDatasetRequest(
-                name=name_of_copy,
-                target_workspace=workspace,
-            ),
+            json_body=CopyDatasetRequest(name=name_of_copy, target_workspace=workspace),
         )
 
     def delete(self, name: str, workspace: Optional[str] = None):
@@ -254,7 +306,7 @@ class Argilla:
         if workspace is not None:
             self.set_workspace(workspace)
 
-        datasets_api.delete_dataset(client=self._client, name=name)
+        datasets_api.delete_dataset(client=self.http_client, name=name)
 
     def log(
         self,
@@ -263,9 +315,11 @@ class Argilla:
         workspace: Optional[str] = None,
         tags: Optional[Dict[str, str]] = None,
         metadata: Optional[Dict[str, Any]] = None,
-        batch_size: int = 500,
+        batch_size: int = 100,
         verbose: bool = True,
         background: bool = False,
+        num_threads: int = 0,
+        max_retries: int = 3,
         chunk_size: Optional[int] = None,
     ) -> Union[BulkResponse, Future]:
         """Logs Records to argilla.
@@ -282,6 +336,10 @@ class Argilla:
             background: If True, we will NOT wait for the logging process to finish and return
                 an ``asyncio.Future`` object. You probably want to set ``verbose`` to False
                 in that case.
+            num_threads: If > 0, will use num_thread separate number threads to batches, sending data concurrently.
+                Default to `0`, which means no threading at all.
+            max_retries: Number of retries when logging a batch of records if a `httpx.TransportError` occurs.
+                Default `3`
             chunk_size: DEPRECATED! Use `batch_size` instead.
 
         Returns:
@@ -290,52 +348,24 @@ class Argilla:
             will be returned instead.
 
         """
-        if workspace is not None:
-            self.set_workspace(workspace)
 
-        future = self._agent.log(
-            records=records,
-            name=name,
-            tags=tags,
-            metadata=metadata,
-            batch_size=batch_size,
-            verbose=verbose,
-            chunk_size=chunk_size,
-        )
         if background:
-            return future
+            executor = ThreadPoolExecutor(max_workers=1)
 
-        try:
-            return future.result()
-        finally:
-            future.cancel()
+            return executor.submit(
+                self.log,
+                records=records,
+                name=name,
+                workspace=workspace,
+                tags=tags,
+                metadata=metadata,
+                batch_size=batch_size,
+                verbose=verbose,
+                chunk_size=chunk_size,
+                num_threads=num_threads,
+                max_retries=max_retries,
+            )
 
-    async def log_async(
-        self,
-        records: Union[Record, Iterable[Record], Dataset],
-        name: str,
-        workspace: Optional[str] = None,
-        tags: Optional[Dict[str, str]] = None,
-        metadata: Optional[Dict[str, Any]] = None,
-        batch_size: int = 500,
-        verbose: bool = True,
-        chunk_size: Optional[int] = None,
-    ) -> BulkResponse:
-        """Logs Records to argilla with asyncio.
-
-        Args:
-            records: The record, an iterable of records, or a dataset to log.
-            name: The dataset name.
-            tags: A dictionary of tags related to the dataset.
-            metadata: A dictionary of extra info for the dataset.
-            batch_size: The batch size for a data bulk.
-            verbose: If True, shows a progress bar and prints out a quick summary at the end.
-            chunk_size: DEPRECATED! Use `batch_size` instead.
-
-        Returns:
-            Summary of the response from the REST API
-
-        """
         tags = tags or {}
         metadata = metadata or {}
 
@@ -363,7 +393,7 @@ class Argilla:
             batch_size = chunk_size
 
         if batch_size > self._MAX_BATCH_SIZE:
-            _LOGGER.warning(
+            warnings.warn(
                 "The requested batch size is noticeably large, timeout errors may occur. "
                 f"Consider a batch size smaller than {self._MAX_BATCH_SIZE}",
             )
@@ -380,36 +410,57 @@ class Argilla:
         if record_type is TextClassificationRecord:
             bulk_class = TextClassificationBulkData
             creation_class = CreationTextClassificationRecord
+            task = TaskType.text_classification
         elif record_type is TokenClassificationRecord:
             bulk_class = TokenClassificationBulkData
             creation_class = CreationTokenClassificationRecord
+            task = TaskType.token_classification
         elif record_type is Text2TextRecord:
             bulk_class = Text2TextBulkData
             creation_class = CreationText2TextRecord
+            task = TaskType.text2text
         else:
             raise InputValueError(f"Unknown record type {record_type}. Available values are {Record.__args__}")
 
-        processed, failed = 0, 0
+        try:
+            self.datasets.create(name=name, task=task, workspace=workspace)
+        except AlreadyExistsApiError:
+            pass
+
+        results = []
         with Progress() as progress_bar:
             task = progress_bar.add_task("Logging...", total=len(records), visible=verbose)
 
-            for i in range(0, len(records), batch_size):
-                batch = records[i : i + batch_size]
+            batches = [records[i : i + batch_size] for i in range(0, len(records), batch_size)]
 
-                response = await async_bulk(
-                    client=self._client,
+            @backoff.on_exception(
+                backoff.expo,
+                exception=httpx.TransportError,
+                max_tries=max_retries,
+                backoff_log_level=logging.DEBUG,
+            )
+            def log_batch(batch_info: Tuple[int, list]) -> Tuple[int, int]:
+                batch_id, batch = batch_info
+
+                bulk_result = bulk(
+                    client=self.http_client,
                     name=name,
                     json_body=bulk_class(
-                        tags=tags,
-                        metadata=metadata,
-                        records=[creation_class.from_client(r) for r in batch],
+                        tags=tags, metadata=metadata, records=[creation_class.from_client(r) for r in batch]
                     ),
                 )
 
-                processed += response.parsed.processed
-                failed += response.parsed.failed
-
                 progress_bar.update(task, advance=len(batch))
+                return bulk_result.processed, bulk_result.failed
+
+            if num_threads >= 1:
+                with ThreadPoolExecutor(max_workers=num_threads) as executor:
+                    results.extend(list(executor.map(log_batch, enumerate(batches))))
+            else:
+                results.extend(list(map(log_batch, enumerate(batches))))
+
+        processed_batches, failed_batches = zip(*results)
+        processed, failed = sum(processed_batches), sum(failed_batches)
 
         # TODO: improve logging policy in library
         if verbose:
@@ -417,7 +468,7 @@ class Argilla:
             workspace = self.get_workspace()
             if not workspace:  # Just for backward comp. with datasets with no workspaces
                 workspace = "-"
-            url = f"{self._client.base_url}/datasets/{workspace}/{name}"
+            url = f"{self.http_client.base_url}/datasets/{workspace}/{name}"
             rprint(f"{processed} records logged to [link={url}]{url}[/link]")
 
         # Creating a composite BulkResponse with the total processed and failed
@@ -437,7 +488,7 @@ class Argilla:
         Args:
             name: The dataset name.
             query: An ElasticSearch query with the `query string syntax
-                <https://rubrix.readthedocs.io/en/stable/guides/queries.html>`_
+                <https://docs.argilla.io/en/latest/guides/query_datasets.html>`_
             ids: If provided, deletes dataset records with given ids.
             discard_only: If `True`, matched records won't be deleted. Instead, they will be marked as `Discarded`
             discard_when_forbidden: Only super-user or dataset creator can delete records from a dataset.
@@ -473,6 +524,8 @@ class Argilla:
         sort: Optional[List[Tuple[str, str]]] = None,
         id_from: Optional[str] = None,
         batch_size: int = 250,
+        include_vectors: bool = True,
+        include_metrics: bool = True,
         as_pandas=None,
     ) -> Dataset:
         """Loads a argilla dataset.
@@ -488,9 +541,16 @@ class Argilla:
             id_from: If provided, starts gathering the records starting from that Record.
                 As the Records returned with the load method are sorted by ID, ´id_from´
                 can be used to load using batches.
+            batch_size: If provided, load `batch_size` samples per request. A lower batch
+                size may help avoid timeouts.
+            include_vectors: When set to `False`, indicates that the record data will be retrieved excluding its vectors,
+                if any. By default, this parameter is set to `True`, meaning that vector data will be included.
+            include_metrics: When set to `False`, indicates that the record data will be retrieved excluding its metrics.
+                By default, this parameter is set to `True`, meaning that metrics will be included.
             as_pandas: DEPRECATED! To get a pandas DataFrame do
                 ``rg.load('my_dataset').to_pandas()``.
 
+
         Returns:
             A argilla dataset.
 
@@ -520,11 +580,13 @@ class Argilla:
             sort=sort,
             id_from=id_from,
             batch_size=batch_size,
+            include_vectors=include_vectors,
+            include_metrics=include_metrics,
         )
 
     def dataset_metrics(self, name: str) -> List[MetricInfo]:
-        response = datasets_api.get_dataset(self._client, name)
-        response = metrics_api.get_dataset_metrics(self._client, name=name, task=response.parsed.task)
+        response = datasets_api.get_dataset(self.http_client, name)
+        response = metrics_api.get_dataset_metrics(self.http_client, name=name, task=response.parsed.task)
 
         return response.parsed
 
@@ -542,13 +604,13 @@ class Argilla:
         interval: Optional[float] = None,
         size: Optional[int] = None,
     ) -> MetricResults:
-        response = datasets_api.get_dataset(self._client, name)
+        response = datasets_api.get_dataset(self.http_client, name)
 
         metric_ = self.get_metric(name, metric=metric)
         assert metric_ is not None, f"Metric {metric} not found !!!"
 
         response = metrics_api.compute_metric(
-            self._client,
+            self.http_client,
             name=name,
             task=response.parsed.task,
             metric=metric,
@@ -564,7 +626,7 @@ class Argilla:
         for rule in rules:
             try:
                 text_classification_api.add_dataset_labeling_rule(
-                    self._client,
+                    self.http_client,
                     name=dataset,
                     rule=rule,
                 )
@@ -582,34 +644,34 @@ class Argilla:
         for rule in rules:
             try:
                 text_classification_api.update_dataset_labeling_rule(
-                    self._client,
+                    self.http_client,
                     name=dataset,
                     rule=rule,
                 )
             except NotFoundApiError:
                 _LOGGER.info(f"Rule {rule} does not exists, creating...")
-                text_classification_api.add_dataset_labeling_rule(self._client, name=dataset, rule=rule)
+                text_classification_api.add_dataset_labeling_rule(self.http_client, name=dataset, rule=rule)
             except Exception as ex:
                 _LOGGER.warning(f"Cannot update rule {rule}: {ex}")
 
     def delete_dataset_labeling_rules(self, dataset: str, rules: List[LabelingRule]):
         for rule in rules:
             try:
-                text_classification_api.delete_dataset_labeling_rule(self._client, name=dataset, rule=rule)
+                text_classification_api.delete_dataset_labeling_rule(self.http_client, name=dataset, rule=rule)
             except Exception as ex:
                 _LOGGER.warning(f"Cannot delete rule {rule}: {ex}")
         """Deletes the dataset labeling rules"""
         for rule in rules:
-            text_classification_api.delete_dataset_labeling_rule(self._client, name=dataset, rule=rule)
+            text_classification_api.delete_dataset_labeling_rule(self.http_client, name=dataset, rule=rule)
 
     def fetch_dataset_labeling_rules(self, dataset: str) -> List[LabelingRule]:
-        response = text_classification_api.fetch_dataset_labeling_rules(self._client, name=dataset)
+        response = text_classification_api.fetch_dataset_labeling_rules(self.http_client, name=dataset)
 
         return [LabelingRule.parse_obj(data) for data in response.parsed]
 
     def rule_metrics_for_dataset(self, dataset: str, rule: LabelingRule) -> LabelingRuleMetricsSummary:
         response = text_classification_api.dataset_rule_metrics(
-            self._client, name=dataset, query=rule.query, label=rule.label
+            self.http_client, name=dataset, query=rule.query, label=rule.label
         )
 
         return LabelingRuleMetricsSummary.parse_obj(response.parsed)
@@ -624,6 +686,8 @@ class Argilla:
         sort: Optional[List[Tuple[str, str]]] = None,
         id_from: Optional[str] = None,
         batch_size: int = 250,
+        include_vectors: bool = True,
+        include_metrics: bool = True,
     ) -> Dataset:
         dataset = self.datasets.find_by_name(name=name)
         task = dataset.task
@@ -646,6 +710,11 @@ class Argilla:
             if sort is not None:
                 _LOGGER.warning("Results are sorted by vector similarity, so 'sort' parameter is ignored.")
 
+            if not (include_metrics and include_vectors):
+                _LOGGER.warning(
+                    "Metrics and vectors cannot be excluded when using vector search. These parameters will be ignored."
+                )
+
             vector_search = VectorSearch(name=vector[0], value=vector[1])
             results = self.search.search_records(
                 name=name,
@@ -658,9 +727,29 @@ class Argilla:
 
             return dataset_class(results.records)
 
+        all_supported_fields = {
+            "metadata.*",
+            "status",
+            "event_timestamp",
+            "annotation*",
+            "prediction*",
+            "search_keywords",
+            "inputs.*",
+            "multi_label",
+            "explanation*",
+            "text",
+            "tokens",
+        }
+
+        if include_vectors:
+            all_supported_fields.add("vectors.*")
+
+        if include_metrics:
+            all_supported_fields.add("metrics.*")
+
         records = self.datasets.scan(
             name=name,
-            projection={"*"},
+            projection=all_supported_fields,
             limit=limit,
             sort=sort,
             id_from=id_from,
