@@ -25,10 +25,10 @@ from typing import Any, Dict, List, Optional, Tuple, Union
 
 import pandas as pd
 from deprecated import deprecated
-from pydantic import BaseModel, Field, PrivateAttr, root_validator, validator
+from pydantic import BaseModel, Field, PrivateAttr, conint, constr, root_validator, validator
 
 from argilla import _messages
-from argilla._constants import DEFAULT_MAX_KEYWORD_LENGTH
+from argilla._constants import _JS_MAX_SAFE_INTEGER, DEFAULT_MAX_KEYWORD_LENGTH, PROTECTED_METADATA_FIELD_PREFIX
 from argilla.utils.span_utils import SpanUtils
 
 _LOGGER = logging.getLogger(__name__)
@@ -37,10 +37,34 @@ Vectors = Dict[str, List[float]]
 
 
 class Framework(Enum):
+    """Frameworks supported by Argilla
+
+    Options:
+        transformers: Transformers
+        peft: PEFT Transformers library
+        setfit: SetFit Transformers library
+        spacy: Spacy Explosion
+        spacy-transformers: Spacy Transformers Explosion library
+        span_marker: SpanMarker Tom Aarsen library
+        spark-nlp: Spark NLP John Snow Labs library
+        openai: OpenAI LLMs
+        trl: Transformer Reinforcement Learning
+        trlx: Transformer Reinforcement Learning X
+        sentence-transformers: Sentence Transformers library
+    """
+
     TRANSFORMERS = "transformers"
+    PEFT = "peft"
     SETFIT = "setfit"
     SPACY = "spacy"
+    SPACY_TRANSFORMERS = "spacy-transformers"
+    SPAN_MARKER = "span_marker"
     SPARK_NLP = "spark-nlp"
+    OPENAI = "openai"
+    TRL = "trl"
+    TRLX = "trlx"
+    SENTENCE_TRANSFORMERS = "sentence-transformers"
+    # AUTOTRAIN = "autotrain"
 
     @classmethod
     def _missing_(cls, value):
@@ -62,7 +86,9 @@ class _Validators(BaseModel):
             return metadata
 
         default_length_exceeded = False
-        for v in metadata.values():
+        for k, v in metadata.items():
+            if k.startswith(PROTECTED_METADATA_FIELD_PREFIX):
+                continue
             if isinstance(v, str) and len(v) > DEFAULT_MAX_KEYWORD_LENGTH:
                 default_length_exceeded = True
                 break
@@ -73,7 +99,7 @@ class _Validators(BaseModel):
                 " values will be truncated by keeping only the last"
                 f" {DEFAULT_MAX_KEYWORD_LENGTH} characters. " + _messages.ARGILLA_METADATA_FIELD_WARNING_MESSAGE
             )
-            warnings.warn(message, UserWarning)
+            warnings.warn(message, UserWarning, stacklevel=2)
 
         return metadata
 
@@ -83,10 +109,29 @@ class _Validators(BaseModel):
             return {}
         return v
 
-    @validator("id", check_fields=False, always=True)
-    def _none_to_generated_uid64(cls, v):
+    @validator("id", check_fields=False, pre=True, always=True)
+    def _normalize_id(cls, v):
         if v is None:
             return str(uuid.uuid4())
+        if isinstance(v, int):
+            message = (
+                f"Integer ids won't be supported in future versions. We recommend to start using strings instead. "
+                "For datasets already containing integer values we recommend migrating them to avoid deprecation issues. "
+                "See https://docs.argilla.io/en/latest/getting_started/installation/configurations"
+                "/database_migrations.html#elasticsearch"
+            )
+            warnings.warn(message, DeprecationWarning, stacklevel=2)
+            # See https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER
+            if v > _JS_MAX_SAFE_INTEGER:
+                message = (
+                    "You've provided a big integer value. Use a string instead, otherwise you may experience some "
+                    "problems using the UI. See "
+                    "https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number"
+                    "/MAX_SAFE_INTEGER"
+                )
+                warnings.warn(message, UserWarning, stacklevel=2)
+        elif not isinstance(v, str):
+            raise TypeError(f"Invalid type for id. Expected {int} or {str}; found:{type(v)}")
         return v
 
     @validator("prediction_agent", check_fields=False)
@@ -267,7 +312,7 @@ class TextClassificationRecord(_Validators):
             and values.get("inputs") is not None
             and values["text"] != values["inputs"].get("text")
         ):
-            raise ValueError("For a TextClassificationRecord you must provide either 'text' or" " 'inputs'")
+            raise ValueError("For a TextClassificationRecord you must provide either 'text' or 'inputs'")
 
         if values.get("text") is not None:
             values["inputs"] = dict(text=values["text"])
@@ -329,7 +374,6 @@ class TokenClassificationRecord(_Validators):
         ...     vectors = {
         ...            "bert_base_uncased": [3.2, 4.5, 5.6, 8.9]
         ...          }
-        ...       ]
         ... )
     """
 
@@ -359,7 +403,7 @@ class TokenClassificationRecord(_Validators):
         **data,
     ):
         if text is None and tokens is None:
-            raise AssertionError("Missing fields: At least one of `text` or `tokens` argument must be" " provided!")
+            raise AssertionError("Missing fields: At least one of `text` or `tokens` argument must be provided!")
 
         if (data.get("annotation") or data.get("prediction")) and text is None:
             raise AssertionError("Missing field `text`: " "char level spans must be provided with a raw text sentence")
