@@ -47,6 +47,14 @@ class _ClientCommonDefaults:
     def get_timeout(self) -> float:
         return self.timeout
 
+    def update_headers(self, headers: Dict[str, str]):
+        self.headers.update(headers)
+        self.httpx.headers.update(self.get_headers())
+
+    @property
+    def httpx(self):
+        return self.__httpx__
+
 
 @dataclasses.dataclass
 class _Client:
@@ -92,6 +100,7 @@ class Client(_ClientCommonDefaults, _Client):
             cookies=self.get_cookies(),
             timeout=self.get_timeout(),
         )
+        # TODO: Remove this NOW!!!!
         self.__http_async__ = httpx.AsyncClient(
             base_url=self.base_url,
             headers=self.get_headers(),
@@ -101,24 +110,15 @@ class Client(_ClientCommonDefaults, _Client):
 
     def __del__(self):
         del self.__httpx__
-        del self.__http_async__
 
     def __hash__(self):
         return hash(self.base_url)
 
     def with_httpx_error_handler(func):
         def wrap_error(base_url: str):
-            err_str = f"Your Api endpoint at {base_url} is not available or not" " responding."
+            err_str = f"Your Api endpoint at {base_url} is not available or not responding."
             raise BaseClientError(err_str) from None
 
-        @functools.wraps(func)
-        async def inner_async(self, *args, **kwargs):
-            try:
-                result = await func(self, *args, **kwargs)
-                return result
-            except httpx.ConnectError as err:  # noqa: F841
-                return wrap_error(self.base_url)
-
         @functools.wraps(func)
         def inner(self, *args, **kwargs):
             try:
@@ -127,8 +127,7 @@ class Client(_ClientCommonDefaults, _Client):
             except httpx.ConnectError as err:  # noqa: F841
                 return wrap_error(self.base_url)
 
-        is_coroutine = inspect.iscoroutinefunction(func)
-        return inner_async if is_coroutine else inner
+        return inner
 
     @with_httpx_error_handler
     def get(self, path: str, *args, **kwargs):
@@ -191,24 +190,6 @@ class Client(_ClientCommonDefaults, _Client):
         )
         return build_raw_response(response).parsed
 
-    @with_httpx_error_handler
-    async def post_async(
-        self,
-        path: str,
-        *args,
-        json: Optional[dict] = None,
-        **kwargs,
-    ):
-        path = self._normalize_path(path)
-        body = self._normalize_body(json)
-        return await self.__http_async__.post(
-            url=path,
-            headers=self.get_headers(),
-            json=body,
-            *args,
-            **kwargs,
-        )
-
     @with_httpx_error_handler
     def put(
         self,
@@ -248,25 +229,6 @@ class Client(_ClientCommonDefaults, _Client):
         )
         return build_raw_response(response).parsed
 
-    @with_httpx_error_handler
-    def stream(
-        self,
-        path: str,
-        *args,
-        json: Optional[dict] = None,
-        **kwargs,
-    ):
-        path = self._normalize_path(path)
-        body = self._normalize_body(json)
-        return self.__httpx__.stream(
-            url=path,
-            headers=self.get_headers(),
-            json=body,
-            timeout=None,  # Avoid timeouts. TODO: Improve the logic
-            *args,
-            **kwargs,
-        )
-
     @staticmethod
     def _normalize_path(path: str) -> str:
         path = path.strip()
@@ -287,11 +249,7 @@ ResponseType = TypeVar("ResponseType")
 
 
 @dataclasses.dataclass
-class AuthenticatedClient(
-    Client,
-    _ClientCommonDefaults,
-    _AuthenticatedClient,
-):
+class AuthenticatedClient(Client, _ClientCommonDefaults, _AuthenticatedClient):
     """A Client which has been authenticated for use on secured endpoints"""
 
     def __hash__(self):
