@@ -29,9 +29,7 @@ from argilla.client.sdk.commons.errors import (
 )
 
 
-def handle_response_error(
-    response: httpx.Response, parse_response: bool = True, **client_ctx
-):
+def handle_response_error(response: httpx.Response, parse_response: bool = True, **client_ctx):
     try:
         response_content = response.json() if parse_response else {}
     except JSONDecodeError:
@@ -56,6 +54,7 @@ def handle_response_error(
     elif response.status_code == ValidationApiError.HTTP_STATUS:
         error_type = ValidationApiError
         error_args["client_ctx"] = client_ctx
+        error_args["params"] = {}
     elif response.status_code == MethodNotAllowedApiError.HTTP_STATUS:
         error_type = MethodNotAllowedApiError
     elif response.status_code == GenericApiError.HTTP_STATUS:
