@@ -24,7 +24,6 @@ class TaskType(str, Enum):
     text_classification = "TextClassification"
     token_classification = "TokenClassification"
     text2text = "Text2Text"
-    multi_task_text_token_classification = "MultitaskTextTokenClassification"
 
     @classmethod
     def _missing_(cls, value):
@@ -40,8 +39,8 @@ class BaseDatasetModel(BaseModel):
 
 
 class Dataset(BaseDatasetModel):
+    id: str
     task: TaskType
-    owner: str = None
     workspace: str = None
     created_at: datetime = None
     last_updated: datetime = None
