@@ -21,7 +21,7 @@ import numpy as np
 
 from argilla import DatasetForTextClassification, TextClassificationRecord
 from argilla.labeling.text_classification.weak_labels import WeakLabels, WeakMultiLabels
-from argilla.utils.dependency import requires_version
+from argilla.utils.dependency import requires_dependencies
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -36,7 +36,7 @@ class TieBreakPolicy(Enum):
     @classmethod
     def _missing_(cls, value):
         raise ValueError(
-            f"{value} is not a valid {cls.__name__}, please select one of" f" {list(cls._value2member_map_.keys())}"
+            f"{value} is not a valid {cls.__name__}, please select one of {list(cls._value2member_map_.keys())}"
         )
 
 
@@ -311,7 +311,7 @@ class MajorityVoter(LabelModel):
 
         return records_with_prediction
 
-    @requires_version("scikit-learn")
+    @requires_dependencies("scikit-learn")
     def score(
         self,
         tie_break_policy: Union[TieBreakPolicy, str] = "abstain",
@@ -412,7 +412,7 @@ class MajorityVoter(LabelModel):
                 prediction[i] = equal_prob_idx[random_idx]
         else:
             raise NotImplementedError(
-                f"The tie break policy '{tie_break_policy.value}' is not implemented" " for MajorityVoter!"
+                f"The tie break policy '{tie_break_policy.value}' is not implemented for MajorityVoter!"
             )
 
         return annotation, prediction
@@ -438,7 +438,7 @@ class MajorityVoter(LabelModel):
         return annotation, prediction
 
 
-@requires_version("snorkel")
+@requires_dependencies("snorkel")
 class Snorkel(LabelModel):
     """The label model by `Snorkel <https://github.com/snorkel-team/snorkel/>`__.
 
@@ -606,7 +606,7 @@ class Snorkel(LabelModel):
 
         return DatasetForTextClassification(records_with_prediction)
 
-    @requires_version("scikit-learn")
+    @requires_dependencies("scikit-learn")
     def score(
         self,
         tie_break_policy: Union[TieBreakPolicy, str] = "abstain",
@@ -648,9 +648,7 @@ class Snorkel(LabelModel):
             tie_break_policy = TieBreakPolicy(tie_break_policy)
 
         if self._weak_labels.annotation().size == 0:
-            raise MissingAnnotationError(
-                "You need annotated records to compute scores/metrics for your label" " model."
-            )
+            raise MissingAnnotationError("You need annotated records to compute scores/metrics for your label model.")
 
         l_pred = self._weak_labels.matrix(has_annotation=True)
         if self._need_remap:
@@ -678,8 +676,7 @@ class Snorkel(LabelModel):
         )
 
 
-@requires_version("flyingsquid")
-@requires_version("pgmpy")
+@requires_dependencies(["flyingsquid", "pgmpy"])
 class FlyingSquid(LabelModel):
     """The label model by `FlyingSquid <https://github.com/HazyResearch/flyingsquid>`__.
 
@@ -834,7 +831,7 @@ class FlyingSquid(LabelModel):
                 pred_for_rec = [(self._weak_labels.labels[i], prob[i]) for i in np.argsort(prob)[::-1]]
             else:
                 raise NotImplementedError(
-                    f"The tie break policy '{tie_break_policy.value}' is not" " implemented for FlyingSquid!"
+                    f"The tie break policy '{tie_break_policy.value}' is not implemented for FlyingSquid!"
                 )
 
             records_with_prediction.append(rec.copy(deep=True))
@@ -860,7 +857,7 @@ class FlyingSquid(LabelModel):
             NotFittedError: If the label model was still not fitted.
         """
         if not self._models:
-            raise NotFittedError("This FlyingSquid instance is not fitted yet. Call `fit` before using" " this model.")
+            raise NotFittedError("This FlyingSquid instance is not fitted yet. Call `fit` before using this model.")
         # create predictions for each label
         if self._weak_labels.cardinality > 2:
             probas = np.zeros((len(weak_label_matrix), self._weak_labels.cardinality))
@@ -876,7 +873,7 @@ class FlyingSquid(LabelModel):
 
         return probas
 
-    @requires_version("scikit-learn")
+    @requires_dependencies("scikit-learn")
     def score(
         self,
         tie_break_policy: Union[TieBreakPolicy, str] = "abstain",
@@ -945,7 +942,7 @@ class FlyingSquid(LabelModel):
                 prediction[i] = equal_prob_idx[random_idx]
         else:
             raise NotImplementedError(
-                f"The tie break policy '{tie_break_policy.value}' is not implemented" " for FlyingSquid!"
+                f"The tie break policy '{tie_break_policy.value}' is not implemented for FlyingSquid!"
             )
 
         return classification_report(
