@@ -21,6 +21,11 @@ from argilla.client import api
 from argilla.metrics import helpers
 from argilla.metrics.models import MetricSummary
 
+_UNUSED_METRIC_WARNING_MESSAGE = (
+    "This metric won't be computed anymore and this function will disappear in a next release!!\n"
+    "The metric could return empty results for new Argilla servers"
+)
+
 
 def tokens_length(name: str, query: Optional[str] = None, interval: int = 1) -> MetricSummary:
     """Computes the text length distribution measured in number of tokens.
@@ -40,6 +45,8 @@ def tokens_length(name: str, query: Optional[str] = None, interval: int = 1) ->
         >>> summary.visualize() # will plot a histogram with results
         >>> summary.data # the raw histogram data with bins of size 5
     """
+    warnings.warn(message=_UNUSED_METRIC_WARNING_MESSAGE, category=DeprecationWarning)
+
     metric = api.active_api().compute_metric(name, metric="tokens_length", query=query, interval=interval)
 
     return MetricSummary.new_summary(
@@ -98,6 +105,8 @@ def token_length(name: str, query: Optional[str] = None) -> MetricSummary:
         >>> summary.visualize() # will plot a histogram with results
         >>> summary.data # The token length distribution
     """
+    warnings.warn(message=_UNUSED_METRIC_WARNING_MESSAGE, category=DeprecationWarning)
+
     metric = api.active_api().compute_metric(name, metric="token_length", query=query)
 
     return MetricSummary.new_summary(
@@ -202,6 +211,8 @@ def mention_length(
         >>> summary.visualize() # will plot a histogram chart with results
         >>> summary.data # the raw histogram data with bins of size 2
     """
+    warnings.warn(message=_UNUSED_METRIC_WARNING_MESSAGE, category=DeprecationWarning)
+
     level = (level or "token").lower().strip()
     accepted_levels = ["token", "char"]
     assert level in accepted_levels, f"Unexpected value for level. Accepted values are {accepted_levels}"
@@ -224,10 +235,7 @@ def mention_length(
 
 
 def entity_labels(
-    name: str,
-    query: Optional[str] = None,
-    compute_for: Union[str, ComputeFor] = Predictions,
-    labels: int = 50,
+    name: str, query: Optional[str] = None, compute_for: Union[str, ComputeFor] = Predictions, labels: int = 50
 ) -> MetricSummary:
     """Computes the entity labels distribution
 
@@ -265,10 +273,7 @@ def entity_labels(
 
 
 def entity_density(
-    name: str,
-    query: Optional[str] = None,
-    compute_for: Union[str, ComputeFor] = Predictions,
-    interval: float = 0.005,
+    name: str, query: Optional[str] = None, compute_for: Union[str, ComputeFor] = Predictions, interval: float = 0.005
 ) -> MetricSummary:
     """Computes the entity density distribution. Then entity density is calculated at
     record level for each mention as ``mention_length/tokens_length``
@@ -289,6 +294,9 @@ def entity_density(
         >>> summary = entity_density(name="example-dataset")
         >>> summary.visualize()
     """
+
+    warnings.warn(message=_UNUSED_METRIC_WARNING_MESSAGE, category=DeprecationWarning)
+
     metric = api.active_api().compute_metric(
         name,
         metric=f"{_check_compute_for(compute_for)}_entity_density",
@@ -306,9 +314,7 @@ def entity_density(
 
 
 def entity_capitalness(
-    name: str,
-    query: Optional[str] = None,
-    compute_for: Union[str, ComputeFor] = Predictions,
+    name: str, query: Optional[str] = None, compute_for: Union[str, ComputeFor] = Predictions
 ) -> MetricSummary:
     """Computes the entity capitalness. The entity capitalness splits the entity mention shape in 4 groups:
 
