@@ -20,10 +20,7 @@ from pydantic import BaseModel
 from argilla.client.sdk.token_classification.models import TokenClassificationQuery
 from argilla.server.apis.v0.models.commons.params import CommonTaskHandlerDependencies
 from argilla.server.apis.v0.models.text2text import Text2TextQuery, Text2TextRecord
-from argilla.server.apis.v0.models.text_classification import (
-    TextClassificationQuery,
-    TextClassificationRecord,
-)
+from argilla.server.apis.v0.models.text_classification import TextClassificationQuery, TextClassificationRecord
 from argilla.server.apis.v0.models.token_classification import TokenClassificationRecord
 from argilla.server.commons.config import TasksFactory
 from argilla.server.models import User
@@ -55,7 +52,7 @@ def configure_router(router: APIRouter):
         search: SearchRecordsService = Depends(SearchRecordsService.get_instance),
         current_user: User = Security(auth.get_current_user),
     ) -> RecordType:
-        found = service.find_by_name(
+        found = await service.find_by_name(
             user=current_user,
             name=name,
             workspace=request_deps.workspace,
@@ -87,7 +84,7 @@ def configure_router(router: APIRouter):
         storage: RecordsStorageService = Depends(RecordsStorageService.get_instance),
         current_user: User = Security(auth.get_current_user),
     ):
-        found = service.find_by_name(
+        found = await service.find_by_name(
             user=current_user,
             name=name,
             workspace=request_deps.workspace,
