@@ -13,21 +13,11 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import itertools
-from typing import Iterable, Optional
-
 from fastapi import APIRouter, Depends, Query, Security
-from fastapi.responses import StreamingResponse
 
-from argilla.server.apis.v0.handlers import (
-    metrics,
-    token_classification_dataset_settings,
-)
+from argilla.server.apis.v0.handlers import metrics, token_classification_dataset_settings
 from argilla.server.apis.v0.models.commons.model import BulkResponse
-from argilla.server.apis.v0.models.commons.params import (
-    CommonTaskHandlerDependencies,
-    RequestPagination,
-)
+from argilla.server.apis.v0.models.commons.params import CommonTaskHandlerDependencies, RequestPagination
 from argilla.server.apis.v0.models.token_classification import (
     TokenClassificationAggregations,
     TokenClassificationBulkRequest,
@@ -39,17 +29,11 @@ from argilla.server.apis.v0.models.token_classification import (
 from argilla.server.apis.v0.validators.token_classification import DatasetValidator
 from argilla.server.commons.config import TasksFactory
 from argilla.server.commons.models import TaskType
-from argilla.server.errors import EntityNotFoundError
 from argilla.server.models import User
-from argilla.server.schemas.datasets import CreateDatasetRequest
 from argilla.server.security import auth
-from argilla.server.services.datasets import DatasetsService, ServiceBaseDataset
-from argilla.server.services.tasks.token_classification import (
-    TokenClassificationService,
-)
-from argilla.server.services.tasks.token_classification.metrics import (
-    TokenClassificationMetrics,
-)
+from argilla.server.services.datasets import DatasetsService
+from argilla.server.services.tasks.token_classification import TokenClassificationService
+from argilla.server.services.tasks.token_classification.metrics import TokenClassificationMetrics
 from argilla.server.services.tasks.token_classification.model import (
     ServiceTokenClassificationQuery,
     ServiceTokenClassificationRecord,
@@ -58,8 +42,7 @@ from argilla.server.services.tasks.token_classification.model import (
 
 def configure_router():
     task_type = TaskType.token_classification
-    base_endpoint = f"/{{name}}/{task_type}"
-    new_base_endpoint = f"/{task_type}/{{name}}"
+    base_endpoint = f"/{{name}}/{task_type.value}"
 
     TasksFactory.register_task(
         task_type=task_type,
@@ -87,40 +70,17 @@ def configure_router():
     ) -> BulkResponse:
         task = task_type
         workspace = common_params.workspace
-        try:
-            dataset = datasets.find_by_name(
-                current_user,
-                name=name,
-                task=task,
-                workspace=workspace,
-            )
-            datasets.update(
-                user=current_user,
-                dataset=dataset,
-                tags=bulk.tags,
-                metadata=bulk.metadata,
-            )
-        except EntityNotFoundError:
-            dataset = CreateDatasetRequest(name=name, workspace=workspace, task=task, **bulk.dict())
-            dataset = datasets.create_dataset(user=current_user, dataset=dataset)
+
+        dataset = await datasets.find_by_name(current_user, name=name, task=task, workspace=workspace)
+
+        await datasets.update(user=current_user, dataset=dataset, tags=bulk.tags, metadata=bulk.metadata)
 
         records = [ServiceTokenClassificationRecord.parse_obj(r) for r in bulk.records]
         # TODO(@frascuchon): validator can be applied in service layer
-        await validator.validate_dataset_records(
-            user=current_user,
-            dataset=dataset,
-            records=records,
-        )
+        await validator.validate_dataset_records(user=current_user, dataset=dataset, records=records)
 
-        result = await service.add_records(
-            dataset=dataset,
-            records=records,
-        )
-        return BulkResponse(
-            dataset=name,
-            processed=result.processed,
-            failed=result.failed,
-        )
+        result = await service.add_records(dataset=dataset, records=records)
+        return BulkResponse(dataset=name, processed=result.processed, failed=result.failed)
 
     @router.post(
         path=f"{base_endpoint}:search",
@@ -128,7 +88,7 @@ def configure_router():
         response_model_exclude_none=True,
         operation_id="search_records",
     )
-    def search_records(
+    async def search_records(
         name: str,
         search: TokenClassificationSearchRequest = None,
         common_params: CommonTaskHandlerDependencies = Depends(),
@@ -144,7 +104,7 @@ def configure_router():
         search = search or TokenClassificationSearchRequest()
         query = search.query or TokenClassificationQuery()
 
-        dataset = datasets.find_by_name(
+        dataset = await datasets.find_by_name(
             user=current_user,
             name=name,
             task=task_type,
