@@ -34,7 +34,7 @@ class LabelsSchema(BaseModel):
 
     labels: Union[List[str], List[Schema]] = Field(description="A set of labels")
 
-    @validator("labels", pre=True)
+    @validator("labels")
     def normalize_labels(cls, labels):
         """
         Labels schema accept a list of strings. Those string will be converted
