@@ -19,13 +19,11 @@ from fastapi import Depends
 from argilla.server.apis.v0.models.dataset_settings import TextClassificationSettings
 from argilla.server.errors import BadRequestError, EntityNotFoundError
 from argilla.server.models import User
-from argilla.server.schemas.datasets import Dataset
+from argilla.server.schemas.v0.datasets import Dataset
 from argilla.server.services.datasets import DatasetsService
 from argilla.server.services.metrics import MetricsService
 from argilla.server.services.tasks.text_classification.metrics import DatasetLabels
-from argilla.server.services.tasks.text_classification.model import (
-    ServiceTextClassificationRecord,
-)
+from argilla.server.services.tasks.text_classification.model import ServiceTextClassificationRecord
 
 
 # TODO(@frascuchon): Move validator and its models to the service layer
