@@ -14,7 +14,7 @@
 
 import dataclasses
 from abc import ABCMeta, abstractmethod
-from typing import Any, Dict, Iterable, List, Optional, Tuple
+from typing import Any, Dict, Iterable, List, Optional, Set, Tuple
 
 from argilla.server.daos.backend.metrics.base import ElasticsearchMetric
 from argilla.server.daos.backend.search.model import BaseQuery, SortConfig
@@ -179,11 +179,7 @@ class IClientAdapter(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def index_documents(
-        self,
-        index: str,
-        docs: List[Dict[str, Any]],
-    ) -> int:
+    def index_documents(self, index: str, docs: List[Dict[str, Any]]) -> int:
         pass
 
     @abstractmethod
