@@ -13,30 +13,18 @@
 #  limitations under the License.
 
 import dataclasses
-from typing import Any, Dict, Iterable, List, Optional, Tuple
+from typing import Any, Dict, Iterable, List, Optional, Set, Tuple
 
 from opensearchpy import OpenSearch, helpers
-from opensearchpy.exceptions import (
-    NotFoundError,
-    OpenSearchException,
-    OpenSearchWarning,
-    RequestError,
-)
+from opensearchpy.exceptions import NotFoundError, OpenSearchException, OpenSearchWarning, RequestError
 from opensearchpy.helpers import BulkIndexError
 
 from argilla.server.daos.backend import query_helpers
 from argilla.server.daos.backend.base import BackendErrorHandler, IndexNotFoundError
 from argilla.server.daos.backend.client_adapters.base import IClientAdapter
 from argilla.server.daos.backend.metrics.base import ElasticsearchMetric
-from argilla.server.daos.backend.search.model import (
-    BaseQuery,
-    SortableField,
-    SortConfig,
-)
-from argilla.server.daos.backend.search.query_builder import (
-    HighlightParser,
-    OpenSearchQueryBuilder,
-)
+from argilla.server.daos.backend.search.model import BaseQuery, SortableField, SortConfig
+from argilla.server.daos.backend.search.query_builder import HighlightParser, OpenSearchQueryBuilder
 
 
 @dataclasses.dataclass
@@ -541,11 +529,7 @@ class OpenSearchClient(IClientAdapter):
                     ignore=400,
                 )
 
-    def index_documents(
-        self,
-        index: str,
-        docs: List[Dict[str, Any]],
-    ) -> int:
+    def index_documents(self, index: str, docs: List[Dict[str, Any]]) -> int:
         actions = (self._doc2bulk_action(index, doc) for doc in docs)
         success, failed = self.bulk(
             index=index,
@@ -554,23 +538,15 @@ class OpenSearchClient(IClientAdapter):
         return len(failed)
 
     @staticmethod
-    def _doc2bulk_action(
-        index: str,
-        doc: Dict[str, Any],
-    ) -> Dict[str, Any]:
-        def get_id(r):
-            return r.get("id")
+    def _doc2bulk_action(index: str, doc: Dict[str, Any]) -> Dict[str, Any]:
+        doc_id = doc.get("id")
 
-        data = {
-            "_op_type": "index",
-            "_index": index,
-            "_routing": None,  # TODO(@frascuchon): Use a sharding routing
-            **doc,
-        }
+        data = (
+            {"_index": index, "_op_type": "index", **doc}
+            if doc_id is None
+            else {"_index": index, "_id": doc_id, "_op_type": "update", "doc_as_upsert": True, "doc": doc}
+        )
 
-        id = get_id(doc)
-        if id is not None:
-            data["_id"] = id
         return data
 
     def upsert_index_document(
@@ -741,10 +717,10 @@ class OpenSearchClient(IClientAdapter):
         is_phrase_query: bool = True,
         add_sort_info: bool = False,
     ):
-        data = {
-            **document["_source"],
-            "id": document["_id"],
-        }
+        data = document["_source"]
+
+        if "id" not in data:
+            data["id"] = document["_id"]
 
         if add_sort_info and "sort" in document:
             data["sort"] = document["sort"]
