@@ -13,11 +13,18 @@
 #  limitations under the License.
 
 import dataclasses
-from typing import Any, Dict, List, Optional, Union
+import logging
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
 from argilla.server.daos.backend.query_helpers import aggregations
 from argilla.server.helpers import unflatten_dict
 
+if TYPE_CHECKING:
+    from argilla.server.daos.backend.client_adapters.base import IClientAdapter
+
+
+_LOGGER = logging.getLogger(__file__)
+
 
 @dataclasses.dataclass
 class ElasticsearchMetric:
@@ -34,13 +41,14 @@ class ElasticsearchMetric:
     def get_function_arg_names(func):
         return func.__code__.co_varnames
 
-    def aggregation_request(
-        self, *args, **kwargs
-    ) -> Union[Dict[str, Any], List[Dict[str, Any]]]:
+    def aggregation_request(self, *args, **kwargs) -> Optional[Union[Dict[str, Any], List[Dict[str, Any]]]]:
         """
         Configures the summary es aggregation definition
         """
-        return {self.id: self._build_aggregation(*args, **kwargs)}
+        try:
+            return {self.id: self._build_aggregation(*args, **kwargs)}
+        except TypeError as ex:
+            _LOGGER.warning(f"Cannot build metric for metric {self.id}. Error: {ex}. Skipping...")
 
     def aggregation_result(self, aggregation_result: Dict[str, Any]) -> Dict[str, Any]:
         """
@@ -118,14 +126,11 @@ class HistogramAggregation(ElasticsearchMetric):
         if self.fixed_interval:
             interval = self.fixed_interval
 
-        return aggregations.histogram_aggregation(
-            field_name=self.field, script=self.script, interval=interval
-        )
+        return aggregations.histogram_aggregation(field_name=self.field, script=self.script, interval=interval)
 
 
 @dataclasses.dataclass
 class TermsAggregation(ElasticsearchMetric):
-
     field: str = None
     script: Union[str, Dict[str, Any]] = None
     fixed_size: Optional[int] = None
@@ -206,7 +211,10 @@ class WordCloudAggregation(ElasticsearchMetric):
     ) -> Dict[str, Any]:
         field = text_field or self.default_field
         terms_id = f"{self.id}_{field}" if text_field else self.id
-        return TermsAggregation(id=terms_id, field=field,).aggregation_request(
+        return TermsAggregation(
+            id=terms_id,
+            field=field,
+        ).aggregation_request(
             size=size or self.DEFAULT_WORDCOUNT_SIZE
         )[terms_id]
 
@@ -223,7 +231,6 @@ class MetadataAggregations(ElasticsearchMetric):
         index: str,
         size: int = None,
     ) -> List[Dict[str, Any]]:
-
         schema = client.get_property_type(
             index=index,
             property_name="metadata",
