@@ -12,15 +12,17 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+
+import uuid
 import warnings
 from datetime import datetime
 from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
-from uuid import uuid4
 
-from pydantic import BaseModel, Field, root_validator, validator
+from pydantic import BaseModel, Field, conint, constr, root_validator, validator
 from pydantic.generics import GenericModel
 
 from argilla import _messages
+from argilla._constants import _JS_MAX_SAFE_INTEGER, PROTECTED_METADATA_FIELD_PREFIX
 from argilla.server.commons.models import PredictionStatus, TaskStatus, TaskType
 from argilla.server.daos.backend.search.model import BaseRecordsQuery, SortConfig
 from argilla.server.helpers import flatten_dict
@@ -56,7 +58,7 @@ EmbeddingDB = TypeVar("EmbeddingDB", bound=BaseEmbeddingVectorDB)
 
 
 class BaseRecordInDB(GenericModel, Generic[AnnotationDB]):
-    id: Optional[Union[int, str]] = Field(default=None)
+    id: Optional[Union[conint(strict=True), constr(strict=True)]] = None
     metadata: Dict[str, Any] = Field(default=None)
     event_timestamp: Optional[datetime] = None
     status: Optional[TaskStatus] = None
@@ -65,20 +67,20 @@ class BaseRecordInDB(GenericModel, Generic[AnnotationDB]):
 
     vectors: Optional[Dict[str, BaseEmbeddingVectorDB]] = Field(
         None,
-        description="Provide the vector info as a list of key - value dictionary."
+        description="Provide the vector info as a list of key - value dictionary. "
         "The dictionary contains the dimension and dimension sized vector float list",
     )
 
     predictions: Optional[Dict[str, AnnotationDB]] = Field(
         None,
-        description="Provide the prediction info as a key-value dictionary."
-        "The key will represent the agent ant the value the prediction."
+        description="Provide the prediction info as a key-value dictionary. "
+        "The key will represent the agent ant the value the prediction. "
         "Using this way you can skip passing the agent inside of the prediction",
     )
     annotations: Optional[Dict[str, AnnotationDB]] = Field(
         None,
-        description="Provide the annotation info as a key-value dictionary."
-        "The key will represent the agent ant the value the annotation."
+        description="Provide the annotation info as a key-value dictionary. "
+        "The key will represent the agent ant the value the annotation. "
         "Using this way you can skip passing the agent inside the annotation",
     )
 
@@ -114,11 +116,27 @@ class BaseRecordInDB(GenericModel, Generic[AnnotationDB]):
         return values
 
     @validator("id", always=True, pre=True)
-    def default_id_if_none_provided(cls, id: Optional[str]) -> str:
-        """Validates id info and sets a random uuid if not provided"""
-        if id is None:
-            return str(uuid4())
-        return id
+    def _normalize_id(cls, v):
+        if v is None:
+            return str(uuid.uuid4())
+        if isinstance(v, int):
+            message = (
+                f"Integer ids won't be supported in future versions. We recommend to start using strings instead. "
+                "For datasets already containing integer values we recommend migrating them to avoid deprecation issues. "
+                "See https://docs.argilla.io/en/latest/getting_started/installation/configurations"
+                "/database_migrations.html#elasticsearch"
+            )
+            warnings.warn(message, DeprecationWarning)
+            # See https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER
+            if v > _JS_MAX_SAFE_INTEGER:
+                message = (
+                    "You've provided a big integer value. Use a string instead, otherwise you may experience some "
+                    "problems using the UI. See "
+                    "https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number"
+                    "/MAX_SAFE_INTEGER"
+                )
+                warnings.warn(message, UserWarning)
+        return v
 
     @validator("status", always=True)
     def fill_default_value(cls, status: TaskStatus):
@@ -126,9 +144,9 @@ class BaseRecordInDB(GenericModel, Generic[AnnotationDB]):
         return TaskStatus.default if status is None else status
 
     @validator("metadata", pre=True)
-    def flatten_metadata(cls, metadata: Dict[str, Any]):
+    def parse_metadata(cls, metadata: Dict[str, Any]):
         """
-        A fastapi validator for flatten metadata dictionary
+        A FastAPI validator for parsing metadata dictionary
 
         Parameters
         ----------
@@ -141,20 +159,25 @@ class BaseRecordInDB(GenericModel, Generic[AnnotationDB]):
 
         """
         if metadata:
-            metadata = flatten_dict(metadata, drop_empty=True)
-            new_metadata = limit_value_length(
-                data=metadata,
-                max_length=settings.metadata_field_length,
-            )
+            metadata_protected = {}
+            metadata_parsed = {}
 
-            if metadata != new_metadata:
+            for k, v in metadata.items():
+                if k.startswith(PROTECTED_METADATA_FIELD_PREFIX):
+                    metadata_protected[k] = v
+                else:
+                    metadata_parsed[k] = limit_value_length(v, settings.metadata_field_length)
+
+            metadata_parsed = {**flatten_dict(metadata_parsed, drop_empty=True), **metadata_protected}
+
+            if metadata != metadata_parsed:
                 message = (
                     "Some metadata values exceed the max length. Those values will be"
                     f" truncated by keeping only the last {settings.metadata_field_length} characters. "
                     + _messages.ARGILLA_METADATA_FIELD_WARNING_MESSAGE
                 )
                 warnings.warn(message, UserWarning)
-                metadata = new_metadata
+                metadata = metadata_parsed
         return metadata
 
     @classmethod
