@@ -42,15 +42,18 @@ from argilla.server.daos.backend import GenericElasticEngineBackend
 from argilla.server.daos.backend.base import GenericSearchError
 from argilla.server.daos.datasets import DatasetsDAO
 from argilla.server.daos.records import DatasetRecordsDAO
-from argilla.server.database import get_db
+from argilla.server.database import get_async_db
 from argilla.server.errors import (
     APIErrorHandler,
+    BadRequestError,
     ClosedDatasetError,
     EntityAlreadyExistsError,
     EntityNotFoundError,
     ForbiddenOperationError,
+    InvalidTextSearchError,
     MissingInputParamError,
     UnauthorizedError,
+    WrongTaskError,
 )
 from argilla.server.models import User
 from argilla.server.routes import api_router
@@ -84,8 +87,12 @@ def configure_api_exceptions(api: FastAPI):
     api.exception_handler(EntityAlreadyExistsError)(APIErrorHandler.common_exception_handler)
     api.exception_handler(ClosedDatasetError)(APIErrorHandler.common_exception_handler)
     api.exception_handler(ValidationError)(APIErrorHandler.common_exception_handler)
+    api.exception_handler(AssertionError)(APIErrorHandler.common_exception_handler)
+    api.exception_handler(WrongTaskError)(APIErrorHandler.common_exception_handler)
     api.exception_handler(MissingInputParamError)(APIErrorHandler.common_exception_handler)
     api.exception_handler(RequestValidationError)(APIErrorHandler.common_exception_handler)
+    api.exception_handler(InvalidTextSearchError)(APIErrorHandler.common_exception_handler)
+    api.exception_handler(BadRequestError)(APIErrorHandler.common_exception_handler)
 
 
 def configure_api_router(app: FastAPI):
@@ -212,9 +219,10 @@ def configure_telemetry(app: FastAPI):
             print(message, flush=True)
 
 
-def configure_database(app: FastAPI):
-    get_db_wrapper = contextlib.contextmanager(get_db)
+_get_db_wrapper = contextlib.asynccontextmanager(get_async_db)
 
+
+def configure_database(app: FastAPI):
     def _user_has_default_credentials(user: User):
         return user.api_key == DEFAULT_API_KEY or accounts.verify_password(DEFAULT_PASSWORD, user.password_hash)
 
@@ -227,8 +235,8 @@ def configure_database(app: FastAPI):
 
     @app.on_event("startup")
     async def log_default_user_warning_if_present():
-        with get_db_wrapper() as db:
-            default_user = accounts.get_user_by_username(db, DEFAULT_USERNAME)
+        async with _get_db_wrapper() as db:
+            default_user = await accounts.get_user_by_username(db, DEFAULT_USERNAME)
             if default_user and _user_has_default_credentials(default_user):
                 _log_default_user_warning()
 
@@ -255,7 +263,7 @@ async def redirect_api():
 
 
 app = FastAPI(docs_url=None)
-app.mount(settings.base_url, argilla_app)
+app.mount("/", argilla_app)
 
 configure_app_logging(app)
 configure_database(app)
