@@ -12,21 +12,15 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-from typing import Any, Dict, List, Optional, Set, Tuple
+
+from typing import Dict, List, Optional, Set, Tuple
 
 from pydantic import BaseModel, Field, validator
 
 from argilla._constants import DEFAULT_MAX_KEYWORD_LENGTH
 from argilla.server.commons.models import PredictionStatus, TaskType
-from argilla.server.services.datasets import ServiceBaseDataset
-from argilla.server.services.search.model import (
-    ServiceBaseRecordsQuery,
-    ServiceScoreRange,
-)
-from argilla.server.services.tasks.commons import (
-    ServiceBaseAnnotation,
-    ServiceBaseRecord,
-)
+from argilla.server.services.search.model import ServiceBaseRecordsQuery, ServiceScoreRange
+from argilla.server.services.tasks.commons import ServiceBaseAnnotation, ServiceBaseRecord
 from argilla.utils import SpanUtils
 
 PREDICTED_MENTIONS_ES_FIELD_NAME = "predicted_mentions"
@@ -83,19 +77,6 @@ class ServiceTokenClassificationRecord(ServiceBaseRecord[ServiceTokenClassificat
     # TODO: review this.
     _predicted: Optional[PredictionStatus] = Field(alias="predicted")
 
-    def extended_fields(self) -> Dict[str, Any]:
-        return {
-            **super().extended_fields(),
-            # See ../service/service.py
-            PREDICTED_MENTIONS_ES_FIELD_NAME: [
-                {"mention": mention, "entity": entity.label, "score": entity.score}
-                for mention, entity in self.predicted_mentions()
-            ],
-            MENTIONS_ES_FIELD_NAME: [
-                {"mention": mention, "entity": entity.label} for mention, entity in self.annotated_mentions()
-            ],
-        }
-
     def __init__(self, **data):
         super().__init__(**data)
 
