@@ -17,62 +17,53 @@ from typing import List, Union
 
 from datasets import DatasetDict
 
-import argilla as rg
-from argilla.training.utils import (
-    _apply_column_mapping,
-    filter_allowed_args,
-    get_default_args,
-)
-from argilla.utils.dependency import require_version
+from argilla.client.models import TextClassificationRecord, TokenClassificationRecord
+from argilla.training.base import ArgillaTrainerSkeleton
+from argilla.training.utils import _apply_column_mapping, filter_allowed_args, get_default_args
+from argilla.utils.dependency import require_dependencies
 
 
-class ArgillaTransformersTrainer(object):
+class ArgillaTransformersTrainer(ArgillaTrainerSkeleton):
     _logger = logging.getLogger("ArgillaTransformersTrainer")
     _logger.setLevel(logging.INFO)
 
-    require_version("torch")
-    require_version("datasets")
-    require_version("transformers")
-    require_version("evaluate")
-    require_version("seqeval")
+    def __init__(self, *args, **kwargs):
+        require_dependencies(["torch", "datasets", "transformers", "evaluate", "seqeval"])
+        super().__init__(*args, **kwargs)
 
-    def __init__(self, dataset, record_class, multi_label: bool = False, model: str = None, seed: int = None):
         import torch
+        from transformers import (
+            AutoModelForSequenceClassification,
+            AutoModelForTokenClassification,
+            set_seed,
+        )
+
+        self._transformers_model = None
+        self._transformers_tokenizer = None
+        self._pipeline = None
 
         self.device = "cpu"
         if torch.backends.mps.is_available():
             self.device = "mps"
         elif torch.cuda.is_available():
             self.device = "cuda"
+
+        if self._seed is None:
+            self._seed = 42
+        set_seed(self._seed)
+
+        if self._model is None:
+            self._model = "bert-base-cased"
+            self._logger.warning(f"No model defined. Using the default model {self._model}.")
+
+        if isinstance(self._dataset, DatasetDict):
+            self._train_dataset = self._dataset["train"]
+            self._eval_dataset = self._dataset["test"]
         else:
-            self.device = "cpu"
-
-        if seed is None:
-            seed = 42
-        self._seed = seed
-
-        if model is None:
-            self.model = "microsoft/deberta-v3-base"
-        else:
-            self.model = model
-
-        self._record_class = record_class
-        self._multi_label = multi_label
-
-        if isinstance(dataset, DatasetDict):
-            self._train_dataset = dataset["train"]
-            self._eval_dataset = dataset["test"]
-        else:
-            self._train_dataset = dataset
+            self._train_dataset = self._dataset
             self._eval_dataset = None
 
-        if self._record_class == rg.TextClassificationRecord:
-            if self._multi_label:
-                self.multi_target_strategy = "one-vs-rest"
-                self._column_mapping = {"text": "text", "binarized_label": "label"}
-            else:
-                self.multi_target_strategy = None
-                self._column_mapping = {"text": "text", "label": "label"}
+        if self._record_class == TextClassificationRecord:
             if self._multi_label:
                 self._id2label = dict(enumerate(self._train_dataset.features["label"][0].names))
                 self._label_list = self._train_dataset.features["label"][0].names
@@ -81,103 +72,127 @@ class ArgillaTransformersTrainer(object):
                 self._label_list = self._train_dataset.features["label"].names
             self._label2id = {v: k for k, v in self._id2label.items()}
 
-        elif self._record_class == rg.TokenClassificationRecord:
-            self._column_mapping = {"text": "text", "token": "tokens", "ner_tags": "ner_tags"}
+            self._model_class = AutoModelForSequenceClassification
+
+        elif self._record_class == TokenClassificationRecord:
             self._label_list = self._train_dataset.features["ner_tags"].feature.names
             self._id2label = dict(enumerate(self._label_list))
             self._label2id = {v: k for k, v in self._id2label.items()}
-        else:
-            raise NotImplementedError("rg.Text2TextRecord are not supported")
 
-        self.init_args()
-
-    def init_args(self):
-        from transformers import (
-            AutoModelForSequenceClassification,
-            AutoModelForTokenClassification,
-            TrainingArguments,
-        )
-
-        # self.tokenizer_kwargs = get_default_args(AutoTokenizer.from_pretrained)
-
-        if self._record_class == rg.TextClassificationRecord:
-            self._model_class = AutoModelForSequenceClassification
-            if self._multi_label:
-                self._train_dataset = _apply_column_mapping(self._train_dataset, self._column_mapping)
-                if self._eval_dataset is not None:
-                    self._eval_dataset = _apply_column_mapping(self._eval_dataset, self._column_mapping)
-        elif self._record_class == rg.TokenClassificationRecord:
             self._model_class = AutoModelForTokenClassification
         else:
-            raise NotImplementedError("rg.Text2TextRecords are not supported yet.")
+            raise NotImplementedError("Text2TextRecord is not supported.")
+
+        self.init_training_args()
+
+    def init_training_args(self):
+        import torch
+        from transformers import TrainingArguments
+
+        def convert_to_floats(dataset):
+            dataset.set_format("torch")
+            return dataset.map(
+                lambda x: {"float_label": x["label"].to(torch.float)}, remove_columns=["label"]
+            ).rename_column("float_label", "label")
+
         self.model_kwargs = {}
-        self.model_kwargs["pretrained_model_name_or_path"] = self.model
-        self.model_kwargs["num_labels"] = len(self._label_list)
-        self.model_kwargs["id2label"] = self._id2label
-        self.model_kwargs["label2id"] = self._label2id
-        if self._multi_label:
-            self.model_kwargs["problem_type"] = "multi_label_classification"
+        self.model_kwargs["pretrained_model_name_or_path"] = self._model
+
+        if self._record_class in [TextClassificationRecord, TokenClassificationRecord]:
+            self.model_kwargs["num_labels"] = len(self._label_list)
+            self.model_kwargs["id2label"] = self._id2label
+            self.model_kwargs["label2id"] = self._label2id
+            if self._multi_label:
+                self.model_kwargs["problem_type"] = "multi_label_classification"
+
+            if self._record_class == TextClassificationRecord:
+                columns_mapping = {"text": "text", "label": "binarized_label"}
+                if self._multi_label:
+                    self._train_dataset = _apply_column_mapping(self._train_dataset, columns_mapping)
+                    self._train_dataset = convert_to_floats(self._train_dataset)
+
+                    if self._eval_dataset is not None:
+                        self._eval_dataset = _apply_column_mapping(self._eval_dataset, columns_mapping)
+                        self._eval_dataset = convert_to_floats(self._eval_dataset)
 
         self.trainer_kwargs = get_default_args(TrainingArguments.__init__)
         self.trainer_kwargs["evaluation_strategy"] = "no" if self._eval_dataset is None else "epoch"
         self.trainer_kwargs["logging_steps"] = 30
-
-        self._pipeline = None
+        self.trainer_kwargs["logging_steps"] = 1
+        self.trainer_kwargs["num_train_epochs"] = 1
 
     def init_model(self, new: bool = False):
         from transformers import AutoTokenizer
 
-        self._tokenizer = AutoTokenizer.from_pretrained(self.model_kwargs.get("pretrained_model_name_or_path"))
+        if any(k in self.model_kwargs.get("pretrained_model_name_or_path") for k in ("gpt", "opt", "bloom")):
+            padding_side = "left"
+        else:
+            padding_side = "right"
+
+        self._transformers_tokenizer = AutoTokenizer.from_pretrained(
+            self.model_kwargs.get("pretrained_model_name_or_path"), padding_side=padding_side, add_prefix_space=True
+        )
+        if getattr(self._transformers_tokenizer, "pad_token_id") is None:
+            self._transformers_tokenizer.pad_token_id = self._transformers_tokenizer.eos_token_id
+        if getattr(self._transformers_tokenizer, "model_max_length") is None:
+            self._transformers_tokenizer.model_max_length = 512
+
         if new:
             model_kwargs = self.model_kwargs
         else:
             model_kwargs = {"pretrained_model_name_or_path": self.model_kwargs.get("pretrained_model_name_or_path")}
-        self._model = self._model_class.from_pretrained(**model_kwargs)
+
+        self._transformers_model = self._model_class.from_pretrained(**model_kwargs, return_dict=True)
+        if new:
+            self._transformers_model = self._transformers_model.to(self.device)
 
     def init_pipeline(self):
         import transformers
-        from transformers import pipeline
+        from transformers import AutoModelForQuestionAnswering, pipeline
 
         if self.device == "cuda":
             device = 0
         else:
             device = -1
 
-        if self._record_class == rg.TextClassificationRecord:
+        if self._record_class == TextClassificationRecord:
             if transformers.__version__ >= "4.20.0":
                 kwargs = {"top_k": None}
             else:
                 kwargs = {"return_all_scores": True}
             self._pipeline = pipeline(
                 task="text-classification",
-                model=self._model,
-                tokenizer=self._tokenizer,
+                model=self._transformers_model,
+                tokenizer=self._transformers_tokenizer,
                 device=device,
                 **kwargs,
             )
-        elif self._record_class == rg.TokenClassificationRecord:
+        elif self._record_class == TokenClassificationRecord:
             self._pipeline = pipeline(
                 task="token-classification",
-                model=self._model,
-                tokenizer=self._tokenizer,
+                model=self._transformers_model,
+                tokenizer=self._transformers_tokenizer,
                 aggregation_strategy="first",
                 device=device,
             )
+        elif self._model_class == AutoModelForQuestionAnswering:
+            self._pipeline = pipeline(
+                task="question-answering",
+                model=self._transformers_model,
+                tokenizer=self._transformers_tokenizer,
+                device=device,
+            )
         else:
-            raise NotImplementedError("This is not implemented.")
+            raise NotImplementedError(f"{self._record_class} is not supported yet.")
 
-    def update_config(
-        self,
-        **kwargs,
-    ):
+    def update_config(self, **kwargs):
         """
         Updates the `setfit_model_kwargs` and `setfit_trainer_kwargs` dictionaries with the keyword
         arguments passed to the `update_config` function.
         """
         from transformers import TrainingArguments
 
-        self.trainer_kwargs.update(kwargs)
-        self.trainer_kwargs = filter_allowed_args(TrainingArguments.__init__, **self.trainer_kwargs)
+        self.trainer_kwargs.update(filter_allowed_args(TrainingArguments.__init__, **kwargs))
 
     def __repr__(self):
         formatted_string = []
@@ -193,27 +208,29 @@ class ArgillaTransformersTrainer(object):
 
     def preprocess_datasets(self):
         from transformers import (
+            AutoModelForQuestionAnswering,
             DataCollatorForTokenClassification,
+            DataCollatorWithPadding,
+            DefaultDataCollator,
         )
 
         def text_classification_preprocess_function(examples):
-            tokens = self._tokenizer(examples["text"], truncation=True, padding="max_length", max_length=512)
-            return tokens
+            return self._transformers_tokenizer(examples["text"], truncation=True, max_length=None)
 
         def token_classification_preprocess_function(examples):
-            tokenized_inputs = self._tokenizer(
-                examples["tokens"], truncation=True, padding="max_length", is_split_into_words=True, max_length=512
+            tokenized_inputs = self._transformers_tokenizer(
+                examples["tokens"], truncation=True, is_split_into_words=True
             )
 
             labels = []
             for i, label in enumerate(examples["ner_tags"]):
-                word_ids = tokenized_inputs.word_ids(batch_index=i)  # Map tokens to their respective word.
+                word_ids = tokenized_inputs.word_ids(batch_index=i)
                 previous_word_idx = None
                 label_ids = []
-                for word_idx in word_ids:  # Set the special tokens to -100.
+                for word_idx in word_ids:
                     if word_idx is None:
                         label_ids.append(-100)
-                    elif word_idx != previous_word_idx:  # Only label the first token of a given word.
+                    elif word_idx != previous_word_idx:
                         label_ids.append(label[word_idx])
                     else:
                         label_ids.append(-100)
@@ -223,34 +240,105 @@ class ArgillaTransformersTrainer(object):
             tokenized_inputs["labels"] = labels
             return tokenized_inputs
 
+        def question_answering_preprocess_function(examples):
+            questions = [q.strip() for q in examples["question"]]
+            inputs = self._transformers_tokenizer(
+                questions,
+                examples["context"],
+                truncation="only_second",
+                return_offsets_mapping=True,
+                padding="max_length",
+            )
+
+            offset_mapping = inputs.pop("offset_mapping")
+            answers = examples["answer"]
+            start_positions = []
+            end_positions = []
+
+            for i, offset in enumerate(offset_mapping):
+                answer = answers[i]
+                start_char = answer["answer_start"][0]
+                end_char = answer["answer_start"][0] + len(answer["text"][0])
+                sequence_ids = inputs.sequence_ids(i)
+
+                # Find the start and end of the context
+                idx = 0
+                while sequence_ids[idx] != 1:
+                    idx += 1
+                context_start = idx
+                while sequence_ids[idx] == 1:
+                    idx += 1
+                context_end = idx - 1
+
+                # If the answer is not fully inside the context, label it (0, 0)
+                if offset[context_start][0] > end_char or offset[context_end][1] < start_char:
+                    start_positions.append(0)
+                    end_positions.append(0)
+                else:
+                    # Otherwise it's the start and end token positions
+                    idx = context_start
+                    while idx <= context_end and offset[idx][0] <= start_char:
+                        idx += 1
+                    start_positions.append(idx - 1)
+
+                    idx = context_end
+                    while idx >= context_start and offset[idx][1] >= end_char:
+                        idx -= 1
+                    end_positions.append(idx + 1)
+
+            inputs["start_positions"] = start_positions
+            inputs["end_positions"] = end_positions
+            return inputs
+
         # set correct tokenization
-        if self._record_class == rg.TextClassificationRecord:
+        if self._record_class == TextClassificationRecord:
             preprocess_function = text_classification_preprocess_function
-            self._data_collator = None
-        elif self._record_class == rg.TokenClassificationRecord:
+            self._data_collator = DataCollatorWithPadding(tokenizer=self._transformers_tokenizer)
+            if self._multi_label:
+                remove_columns = ["feat_id", "text", "feat_label"]
+            else:
+                remove_columns = ["id", "text"]
+            replace_labels = True
+        elif self._record_class == TokenClassificationRecord:
             preprocess_function = token_classification_preprocess_function
-            self._data_collator = DataCollatorForTokenClassification(tokenizer=self._tokenizer, max_length=512)
+            self._data_collator = DataCollatorForTokenClassification(tokenizer=self._transformers_tokenizer)
+            remove_columns = ["id", "tokens", "ner_tags"]
+            replace_labels = False
+        elif self._model_class == AutoModelForQuestionAnswering:
+            preprocess_function = question_answering_preprocess_function
+            self._data_collator = DefaultDataCollator()
+            remove_columns = self._train_dataset.column_names
+            replace_labels = False
         else:
-            raise NotImplementedError("")
+            raise NotImplementedError("`Text2TextRecord` is not supported yet.")
+
+        self._tokenized_train_dataset = self._train_dataset.map(
+            preprocess_function, batched=True, remove_columns=remove_columns
+        )
+        if replace_labels:
+            self._tokenized_train_dataset = self._tokenized_train_dataset.rename_column("label", "labels")
 
-        self._tokenized_train_dataset = self._train_dataset.map(preprocess_function, batched=True)
         if self._eval_dataset is not None:
-            self._tokenized_eval_dataset = self._eval_dataset.map(preprocess_function, batched=True)
+            self._tokenized_eval_dataset = self._eval_dataset.map(
+                preprocess_function, batched=True, remove_columns=remove_columns
+            )
+            if replace_labels:
+                self._tokenized_eval_dataset = self._tokenized_eval_dataset.rename_column("label", "labels")
         else:
             self._tokenized_eval_dataset = None
 
     def compute_metrics(self):
         import evaluate
         import numpy as np
+        from transformers import AutoModelForQuestionAnswering
 
         func = None
-        if self._record_class == rg.TextClassificationRecord:
+        if self._record_class == TextClassificationRecord:
             accuracy = evaluate.load("accuracy")
             f1 = evaluate.load("f1", config_name="multilabel")
 
             def compute_metrics_text_classification_multi_label(eval_pred):
                 logits, labels = eval_pred
-
                 # apply sigmoid
                 predictions = (1.0 / (1 + np.exp(-logits))) > 0.5
 
@@ -273,7 +361,7 @@ class ArgillaTransformersTrainer(object):
             else:
                 func = compute_metrics_text_classification
 
-        elif self._record_class == rg.TokenClassificationRecord:
+        elif self._record_class == TokenClassificationRecord:
             seqeval = evaluate.load("seqeval")
 
             def compute_metrics(p):
@@ -298,26 +386,31 @@ class ArgillaTransformersTrainer(object):
                 }
 
             func = compute_metrics
+        elif AutoModelForQuestionAnswering:
+            f1 = evaluate.load("f1")
+
+            def compute_metrics_question_answering(pred):
+                labels = pred.label_ids
+                preds = pred.predictions.argmax(-1)
+
+                # Calculate Exact Match (EM)
+                em = sum([int(p == l) for p, l in zip(preds, labels)]) / len(labels)
+
+                # Calculate F1-score
+                f1_score = f1(labels, preds, average="macro")
+
+                return {"exact_match": em, "f1": f1_score}
+
+            func = compute_metrics_question_answering
         else:
-            raise NotImplementedError("Text2Text is not implemented.")
+            raise NotImplementedError("Other record types are not supported yet.")
         return func
 
-    # @require_version("setfit", "0.6")
-    def train(self, output_dir: str = None):
-        """
-        We create a SetFitModel object from a pretrained model, then create a SetFitTrainer object with
-        the model, and then train the model
-        """
-        from transformers import (
-            Trainer,
-            TrainingArguments,
-        )
+    def train(self, output_dir: str):
+        from transformers import Trainer, TrainingArguments
 
         # check required path argument
-        if output_dir is not None:
-            self.trainer_kwargs["output_dir"] = output_dir
-        else:
-            raise ValueError("You must specify a path to save the model to use `trainer.train(path=<my_path>).")
+        self.trainer_kwargs["output_dir"] = output_dir
 
         # prepare data
         self.init_model(new=True)
@@ -326,11 +419,17 @@ class ArgillaTransformersTrainer(object):
         # get metrics function
         compute_metrics = self.compute_metrics()
 
+        self._transformers_model.to(self.device)
         # set trainer
+        if self.device == "cuda":
+            self.trainer_kwargs["no_cuda"] = False
+        elif self.device == "mps":
+            self.trainer_kwargs["use_mps_device"] = True
         self._training_args = TrainingArguments(**self.trainer_kwargs)
-        self.__trainer = Trainer(
+        self._transformers_trainer = Trainer(
             args=self._training_args,
-            model=self._model,
+            model=self._transformers_model,
+            tokenizer=self._transformers_tokenizer,
             train_dataset=self._tokenized_train_dataset,
             eval_dataset=self._tokenized_eval_dataset,
             compute_metrics=compute_metrics,
@@ -338,9 +437,9 @@ class ArgillaTransformersTrainer(object):
         )
 
         #  train
-        self.__trainer.train()
+        self._transformers_trainer.train()
         if self._tokenized_eval_dataset:
-            self._metrics = self.__trainer.evaluate()
+            self._metrics = self._transformers_trainer.evaluate()
             self._logger.info(self._metrics)
         else:
             self._metrics = None
@@ -349,7 +448,7 @@ class ArgillaTransformersTrainer(object):
 
         self.init_pipeline()
 
-    def predict(self, text: Union[List[str], str], as_argilla_records: bool = True):
+    def predict(self, text: Union[List[str], str], as_argilla_records: bool = True, **kwargs):
         """
         The function takes in a list of strings and returns a list of predictions
 
@@ -362,7 +461,7 @@ class ArgillaTransformersTrainer(object):
           A list of predictions
         """
         if self._pipeline is None:
-            self._logger.warn("Using model without fine-tuning.")
+            self._logger.warning("Using model without fine-tuning.")
             self.init_model(new=False)
             self.init_pipeline()
 
@@ -371,13 +470,13 @@ class ArgillaTransformersTrainer(object):
             text = [text]
             str_input = True
 
-        predictions = self._pipeline(text)
+        predictions = self._pipeline(text, **kwargs)
 
         if as_argilla_records:
             formatted_prediction = []
 
             for val, pred in zip(text, predictions):
-                if self._record_class == rg.TextClassificationRecord:
+                if self._record_class == TextClassificationRecord:
                     formatted_prediction.append(
                         self._record_class(
                             text=val,
@@ -385,7 +484,7 @@ class ArgillaTransformersTrainer(object):
                             multi_label=self._multi_label,
                         )
                     )
-                elif self._record_class == rg.TokenClassificationRecord:
+                elif self._record_class == TokenClassificationRecord:
                     _pred = [(value["entity_group"], value["start"], value["end"]) for value in pred]
                     encoding = self._pipeline.tokenizer(val)
                     word_ids = sorted(set(encoding.word_ids()) - {None})
@@ -419,5 +518,5 @@ class ArgillaTransformersTrainer(object):
         Args:
           output_dir (str): the path to save the model to
         """
-        self._model.save_pretrained(output_dir)
-        self._tokenizer.save_pretrained(output_dir)
+        self._transformers_model.save_pretrained(output_dir)
+        self._transformers_tokenizer.save_pretrained(output_dir)
